



geckodriver --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
geckodriver --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
pytest test_selenium.py
IF %ERRORLEVEL% NEQ 0 exit /B 1
python test_licenses.py --ignore marionette,mozdevice,mozprofile,mozrunner,mozversion,webdriver
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
